@@ -6,7 +6,7 @@ from mail_office.settings import SETTINGS
 
 
 class Command(BaseCommand):
-    def handle(self) -> None:
+    def handle(self, *args, **kwargs) -> None:
         postmen_count = SETTINGS.pop("POSTMEN_COUNT")
 
         mail_office = MailOffice(
