@@ -32,17 +32,17 @@ class EmailMessageManager(models.Manager):
         Allows to next start not ignore messages that have been selected
         for sending, but not sent due to the completion of the application.
         """
-        self.select_for_update() \
+        self.get_queryset().select_for_update() \
             .filter(status=EmailMessage.Statuses.in_sending) \
             .update(status=EmailMessage.Statuses.new)
 
     @atomic
     def choose_to_send(self, quantity: int) -> models.QuerySet["EmailMessage"]:
-        sending_messages = self.filter(
+        sending_messages = self.get_queryset().filter(
             status=EmailMessage.Statuses.new,
             send_time__lte=now()
         )
-        messages_to_send = self.select_for_update().filter(
+        messages_to_send = self.get_queryset().select_for_update().filter(
             id__in=list(
                 sending_messages[:quantity].values_list("pk", flat=True)
             )
